=======
Credits
=======

Development Lead
----------------

* Lucas Levassor <lucaslevassor@gmail.com>
* Søren Dalsgård Petersen <sorpet@dtu.dk>
* Christine Møller Pedersen



Contributors
------------
* Michael Krogh Jensen
* Nikolaus Sonnenschein
* Rasmus John Normand Frandsen




